#ifndef NT2_INCLUDE_FUNCTIONS_ISULPEQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISULPEQUAL_HPP_INCLUDED

#include <nt2/predicates/include/functions/isulpequal.hpp>

#endif
